package com.ruoyi.nanjing.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.nanjing.mapper.TRpWorktrayrealtimeinfoMapper;
import com.ruoyi.nanjing.domain.TRpWorktrayrealtimeinfo;
import com.ruoyi.nanjing.service.ITRpWorktrayrealtimeinfoService;
import com.ruoyi.common.core.text.Convert;

/**
 * 托盘管理Service业务层处理
 * 
 * @author limy
 * @date 2021-01-28
 */
@Service
public class TRpWorktrayrealtimeinfoServiceImpl implements ITRpWorktrayrealtimeinfoService 
{
    @Autowired
    private TRpWorktrayrealtimeinfoMapper tRpWorktrayrealtimeinfoMapper;

    /**
     * 查询托盘管理
     * 
     * @param rfidNum 托盘管理ID
     * @return 托盘管理
     */
    @Override
    public TRpWorktrayrealtimeinfo selectTRpWorktrayrealtimeinfoById(String rfidNum)
    {
        return tRpWorktrayrealtimeinfoMapper.selectTRpWorktrayrealtimeinfoById(rfidNum);
    }

    /**
     * 查询托盘管理列表
     * 
     * @param tRpWorktrayrealtimeinfo 托盘管理
     * @return 托盘管理
     */
    @Override
    public List<TRpWorktrayrealtimeinfo> selectTRpWorktrayrealtimeinfoList(TRpWorktrayrealtimeinfo tRpWorktrayrealtimeinfo)
    {
        return tRpWorktrayrealtimeinfoMapper.selectTRpWorktrayrealtimeinfoList(tRpWorktrayrealtimeinfo);
    }

    /**
     * 新增托盘管理
     * 
     * @param tRpWorktrayrealtimeinfo 托盘管理
     * @return 结果
     */
    @Override
    public int insertTRpWorktrayrealtimeinfo(TRpWorktrayrealtimeinfo tRpWorktrayrealtimeinfo)
    {
        return tRpWorktrayrealtimeinfoMapper.insertTRpWorktrayrealtimeinfo(tRpWorktrayrealtimeinfo);
    }

    /**
     * 修改托盘管理
     * 
     * @param tRpWorktrayrealtimeinfo 托盘管理
     * @return 结果
     */
    @Override
    public int updateTRpWorktrayrealtimeinfo(TRpWorktrayrealtimeinfo tRpWorktrayrealtimeinfo)
    {
        tRpWorktrayrealtimeinfo.setUpdateTime(DateUtils.getNowDate());
        return tRpWorktrayrealtimeinfoMapper.updateTRpWorktrayrealtimeinfo(tRpWorktrayrealtimeinfo);
    }

    /**
     * 删除托盘管理对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTRpWorktrayrealtimeinfoByIds(String ids)
    {
        return tRpWorktrayrealtimeinfoMapper.deleteTRpWorktrayrealtimeinfoByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除托盘管理信息
     * 
     * @param rfidNum 托盘管理ID
     * @return 结果
     */
    @Override
    public int deleteTRpWorktrayrealtimeinfoById(String rfidNum)
    {
        return tRpWorktrayrealtimeinfoMapper.deleteTRpWorktrayrealtimeinfoById(rfidNum);
    }

    @Override
    public List<TRpWorktrayrealtimeinfo> selectrealtimeinfoList(TRpWorktrayrealtimeinfo tRpWorktrayrealtimeinfo) {
        return tRpWorktrayrealtimeinfoMapper.selectrealtimeinfoList(tRpWorktrayrealtimeinfo);
    }
}
